==> haskell-mustache-2.4.2-168-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-mustache.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 mustache
version:              2.4.2
visibility:           public
id:                   mustache-2.4.2-D4K3TV2U57A572N4G2oF66
key:                  mustache-2.4.2-D4K3TV2U57A572N4G2oF66
license:              BSD-3-Clause
copyright:            (c) 2015 - 2022 Justus Adam
maintainer:           dev@justus.science
author:               Justus Adam
homepage:             https://github.com/JustusAdam/mustache
synopsis:             A mustache template parser library.
description:
    Allows parsing and rendering template files with mustache markup. See the
    mustache <http://mustache.github.io/mustache.5.html language reference>.

    Implements the mustache spec version 1.1.3.

    /Note/: Versions including and beyond 0.4 are compatible with ghc 7.8 again.

category:             Development
abi:                  35b844c59613e2a06b58795c5fa46d7c
exposed:              True
exposed-modules:
    Text.Mustache Text.Mustache.Compile Text.Mustache.Parser
    Text.Mustache.Render Text.Mustache.Types

hidden-modules:
    Text.Mustache.Internal Text.Mustache.Internal.Types Paths_mustache

import-dirs:          /usr/lib/ghc-9.4.8/site-local/mustache-2.4.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/mustache-2.4.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/mustache-2.4.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-mustache
hs-libraries:         HSmustache-2.4.2-D4K3TV2U57A572N4G2oF66
depends:
    aeson-2.1.2.1-LpT6Mf0v1IAHC9jBcKu3TC base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7 directory-1.3.7.1
    filepath-1.4.2.2 mtl-2.2.2 parsec-3.1.16.1
    scientific-0.3.7.0-BkypiqTAkpN3suN2c81wMx template-haskell-2.19.0.0
    text-2.0.2 th-lift-0.8.4-3Jqcte1pbUvKHGfrg0advG
    unordered-containers-0.2.20-1zjZuvvQz6A9v2Utwl5wnX
    vector-0.13.1.0-D9au4GPCsbT1DKgXASrr5O

haddock-interfaces:   /usr/share/doc/haskell-mustache/html/mustache.haddock
haddock-html:         /usr/share/doc/haskell-mustache/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-mustache-2.4.2-169-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-mustache.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 mustache
version:              2.4.2
visibility:           public
id:                   mustache-2.4.2-57F5PZhLCA8Hm8u8bsbfCR
key:                  mustache-2.4.2-57F5PZhLCA8Hm8u8bsbfCR
license:              BSD-3-Clause
copyright:            (c) 2015 - 2022 Justus Adam
maintainer:           dev@justus.science
author:               Justus Adam
homepage:             https://github.com/JustusAdam/mustache
synopsis:             A mustache template parser library.
description:
    Allows parsing and rendering template files with mustache markup. See the
    mustache <http://mustache.github.io/mustache.5.html language reference>.

    Implements the mustache spec version 1.1.3.

    /Note/: Versions including and beyond 0.4 are compatible with ghc 7.8 again.

category:             Development
abi:                  13b209164202c8b287b0d4299478f305
exposed:              True
exposed-modules:
    Text.Mustache Text.Mustache.Compile Text.Mustache.Parser
    Text.Mustache.Render Text.Mustache.Types

hidden-modules:
    Text.Mustache.Internal Text.Mustache.Internal.Types Paths_mustache

import-dirs:          /usr/lib/ghc-9.4.8/site-local/mustache-2.4.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/mustache-2.4.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/mustache-2.4.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-mustache
hs-libraries:         HSmustache-2.4.2-57F5PZhLCA8Hm8u8bsbfCR
depends:
    aeson-2.1.2.1-7NKMY9av0haL3nHVKphSJj base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7 directory-1.3.7.1
    filepath-1.4.2.2 mtl-2.2.2 parsec-3.1.16.1
    scientific-0.3.7.0-BkypiqTAkpN3suN2c81wMx template-haskell-2.19.0.0
    text-2.0.2 th-lift-0.8.4-3Jqcte1pbUvKHGfrg0advG
    unordered-containers-0.2.20-1zjZuvvQz6A9v2Utwl5wnX
    vector-0.13.1.0-D9au4GPCsbT1DKgXASrr5O

haddock-interfaces:   /usr/share/doc/haskell-mustache/html/mustache.haddock
haddock-html:         /usr/share/doc/haskell-mustache/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
